@@ -7,7 +7,7 @@ use File::Spec::Functions qw( catdir abs2rel );
 use Params::Util qw( _STRING _INSTANCE );
 require Perl::Dist::WiX::Tag::Directory;
 
-our $VERSION = '1.102_100';
+our $VERSION = '1.102_101';
 $VERSION =~ s/_//ms;
 
 extends 'WiX3::XML::DirectoryRef';
@@ -33,6 +33,8 @@ sub get_directory_object {
 	return undef;
 } ## end sub get_directory_object
 
+
+
 sub search_dir {
 	## no critic (ProhibitExplicitReturnUndef)
 	my $self = shift;
@@ -44,8 +46,8 @@ sub search_dir {
 		%args = @_;
 	} else {
 
-		# TODO: Throw error.
-		PDWiX->throw('Parameters passed to search_dir not a hash or hashref.');
+		PDWiX->throw(
+			'Parameters passed to search_dir not a hash or hashref.');
 	}
 
 	# Set defaults for parameters.
@@ -104,6 +106,8 @@ sub search_dir {
 	return $exact ? undef : $self;
 } ## end sub search_dir
 
+
+
 sub _add_directory_recursive {
 	my $self         = shift;
 	my $path_to_find = shift;
@@ -155,6 +159,14 @@ sub add_directory {
 }
 
 
+
+sub get_id {
+	my $self = shift;
+	return $self->get_directory_id();
+}
+
+
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -234,6 +246,11 @@ tag with the given parameters and adds it as a child of this tag.
 
 The C<parent> parameter does not need to be given, as it is added as this object.
 
+=head2 get_id
+
+Redirects to C<get_directory_id>.
+
+
 =head1 SUPPORT
 
 Bugs should be reported via the CPAN bug tracker at
